Running test.sh will install with:

    $ pip install -r requirements.txt
    $ python setup.py develop

and then use:

    python setup.py test

to trigger the unittests.

See https://github.com/OpenTreeOfLife/peyotl/wiki/installation for further info
The wiki https://github.com/OpenTreeOfLife/peyotl/wiki/testing describes the other tests scripts.
